package com.lz.modules.equipment.service;


import com.baomidou.mybatisplus.extension.service.IService;
import com.lz.common.utils.PageUtils;
import com.lz.modules.equipment.entity.TCount;
import com.lz.modules.equipment.entity.TCountReq;

import java.util.List;

/**
* <p>
* 盘点 服务类
* </p>
*
* @author quyixiao
* @since 2020-08-10
*/
public interface TCountService extends IService<TCount> {



	TCount selectTCountById(Long id);


	Long insertTCount(TCount tCount);


	int updateTCountById(TCount tCount);


	int updateCoverTCountById(TCount tCount);


	int deleteTCountById(Long id);


	TCount selectMaxTCount();

	List<TCount> selectListLimit(int limit);

	PageUtils selectByReq(TCountReq req);
}